@@ -45,7 +45,9 @@ where
     type Map = Self;
     type Struct = Self;
     type Tuple = Self;
-    type Variant = Self;
+    type StructVariant = Self;
+    type TupleVariant = Self;
+    type UnitVariant = Self;
 
     #[inline]
     fn expecting(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
@@ -216,7 +218,17 @@ where
     }
 
     #[inline]
-    fn encode_variant(self) -> Result<Self::Variant, Self::Error> {
+    fn encode_struct_variant(self, _: usize) -> Result<Self::StructVariant, Self::Error> {
+        Ok(self)
+    }
+
+    #[inline]
+    fn encode_tuple_variant(self, _: usize) -> Result<Self::TupleVariant, Self::Error> {
+        Ok(self)
+    }
+
+    #[inline]
+    fn encode_unit_variant(self) -> Result<Self::UnitVariant, Self::Error> {
         Ok(self)
     }
 }
